@@ -12,6 +12,9 @@ class CanvasApplication(QApplication):
     fileOpenRequest = Signal(QUrl)
 
     def __init__(self, argv):
+        if hasattr(Qt, "AA_EnableHighDpiScaling"):
+            # Turn on HighDPI support when available
+            QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
         QApplication.__init__(self, argv)
         self.setAttribute(Qt.AA_DontShowIconsInMenus, True)
 
