@@ -211,6 +211,7 @@ class FileFormat(metaclass=FileFormatMeta):
         EXTENSIONS = ('.ext1', '.ext2', ...)
         DESCRIPTION = 'human-readable file format description'
         SUPPORT_COMPRESSED = False
+        SUPPORT_SPARSE_DATA = False
 
         def read(self):
             ...  # load headers, data, ...
@@ -286,7 +287,7 @@ class FileFormat(metaclass=FileFormatMeta):
         if isinstance(filename, str) and hasattr(data, 'attributes'):
             if all(isinstance(key, str) and isinstance(value, str)
                    for key, value in data.attributes.items()):
-                with open(filename + '.metadata', 'w') as f:
+                with open(filename + '.metadata', 'w', encoding='utf-8') as f:
                     f.write("\n".join("{}: {}".format(*kv)
                                       for kv in data.attributes.items()))
             else:
@@ -302,7 +303,7 @@ class FileFormat(metaclass=FileFormatMeta):
                     table.attributes = pickle.load(f)
             # Unpickling throws different exceptions, not just UnpickleError
             except:
-                with open(filename + '.metadata') as f:
+                with open(filename + '.metadata', encoding='utf-8') as f:
                     table.attributes = OrderedDict(
                         (k.strip(), v.strip())
                         for k, v in (line.split(":", 1)
@@ -681,6 +682,7 @@ class CSVReader(FileFormat):
     DESCRIPTION = 'Comma-separated values'
     DELIMITERS = ',;:\t$ '
     SUPPORT_COMPRESSED = True
+    SUPPORT_SPARSE_DATA = False
     PRIORITY = 20
 
     def read(self):
@@ -755,6 +757,7 @@ class PickleReader(FileFormat):
     """Reader for pickled Table objects"""
     EXTENSIONS = ('.pickle', '.pkl')
     DESCRIPTION = 'Pickled Python object file'
+    SUPPORT_SPARSE_DATA = True
 
     def read(self):
         with open(self.filename, 'rb') as f:
@@ -770,6 +773,7 @@ class BasketReader(FileFormat):
     """Reader for basket (sparse) files"""
     EXTENSIONS = ('.basket', '.bsk')
     DESCRIPTION = 'Basket file'
+    SUPPORT_SPARSE_DATA = True
 
     def read(self):
         def constr_vars(inds):
@@ -794,6 +798,7 @@ class ExcelReader(FileFormat):
     """Reader for excel files"""
     EXTENSIONS = ('.xls', '.xlsx')
     DESCRIPTION = 'Mircosoft Excel spreadsheet'
+    SUPPORT_SPARSE_DATA = False
 
     def __init__(self, filename):
         super().__init__(filename)
@@ -835,6 +840,7 @@ class DotReader(FileFormat):
     EXTENSIONS = ('.dot', '.gv')
     DESCRIPTION = 'Dot graph description'
     SUPPORT_COMPRESSED = True
+    SUPPORT_SPARSE_DATA = False
 
     @classmethod
     def write_graph(cls, filename, graph):
