@@ -299,6 +299,7 @@ class Table(MutableSequence, Storage):
                 if is_sparse == sp.issparse(x):
                     return x
                 elif is_sparse:
+                    x = np.asarray(x)
                     return sp.csc_matrix(x.reshape(-1, 1).astype(np.float))
                 else:
                     return np.ravel(x.toarray())
@@ -801,8 +802,11 @@ class Table(MutableSequence, Storage):
         return "[" + ",\n ".join(str(ex) for ex in self)
 
     def __repr__(self):
-        s = "[" + ",\n ".join(repr(ex) for ex in self[:5])
-        if len(self) > 5:
+        head = 5
+        if self.is_sparse():
+            head = min(self.X.shape[0], head)
+        s = "[" + ",\n ".join(repr(ex) for ex in self[:head])
+        if len(self) > head:
             s += ",\n ..."
         s += "\n]"
         return s
@@ -945,6 +949,12 @@ class Table(MutableSequence, Storage):
                 (self.metas.base is None) and
                 (self.W.base is None))
 
+    def is_sparse(self):
+        """
+        Return `True` if the table stores data in sparse format
+        """
+        return any(sp.issparse(i) for i in [self.X, self.Y, self.metas])
+
     def ensure_copy(self):
         """
         Ensure that the table owns its data; copy arrays when necessary.
@@ -1298,6 +1308,8 @@ class Table(MutableSequence, Storage):
                 m, W, Xcsc = _get_matrix(self.X, Xcsc, col)
             elif col < 0:
                 m, W, Xcsc = _get_matrix(self.metas, Xcsc, col * (-1) - 1)
+                if np.issubdtype(m.dtype, np.dtype(object)):
+                    m = m.astype(float)
             else:
                 m, W, Ycsc = _get_matrix(self._Y, Ycsc, col - self.X.shape[1])
             if var.is_discrete:
@@ -1506,7 +1518,8 @@ class Table(MutableSequence, Storage):
         # metas
         # - feature names and attributes of attributes to metas
         self.metas, metas = np.empty((self.n_rows, 0), dtype=object), []
-        if meta_attr_name not in [m.name for m in table.domain.metas]:
+        if meta_attr_name not in [m.name for m in table.domain.metas] and \
+                table.domain.attributes:
             self.metas = np.array([[a.name] for a in table.domain.attributes],
                                   dtype=object)
             metas.append(StringVariable(meta_attr_name))
