@@ -16,6 +16,7 @@ import numpy
 import sklearn.metrics as skl_metrics
 
 import Orange
+import Orange.evaluation
 from Orange.widgets import widget, settings, gui
 from Orange.widgets.utils.annotated_data import (create_annotated_table,
                                                  ANNOTATED_DATA_SIGNAL_NAME)
@@ -32,8 +33,13 @@ def confusion_matrix(res, index):
 
     Returns: Confusion matrix
     """
-    return skl_metrics.confusion_matrix(
-        res.actual, res.predicted[index])
+    labels = numpy.arange(len(res.domain.class_var.values))
+    if not res.actual.size:
+        # scikit-learn will not return an zero matrix
+        return numpy.zeros((len(labels), len(labels)))
+    else:
+        return skl_metrics.confusion_matrix(
+            res.actual, res.predicted[index], labels=labels)
 
 
 BorderRole = next(gui.OrangeUserRole)
@@ -109,6 +115,7 @@ class OWConfusionMatrix(widget.OWWidget):
 
     class Error(widget.OWWidget.Error):
         no_regression = Msg("Confusion Matrix cannot show regression results.")
+        invalid_values = Msg("Evaluation Results input contains invalid values")
 
     def __init__(self):
         super().__init__()
@@ -238,6 +245,21 @@ class OWConfusionMatrix(widget.OWWidget):
         else:
             self.Error.no_regression.clear()
 
+        nan_values = False
+        if results is not None:
+            assert isinstance(results, Orange.evaluation.Results)
+            if numpy.any(numpy.isnan(results.actual)) or \
+                    numpy.any(numpy.isnan(results.predicted)):
+                # Error out here (could filter them out with a warning
+                # instead).
+                nan_values = True
+                results = data = None
+
+        if nan_values:
+            self.Error.invalid_values()
+        else:
+            self.Error.invalid_values.clear()
+
         self.results = results
         self.data = data
 
@@ -374,6 +396,7 @@ class OWConfusionMatrix(widget.OWWidget):
             data = Orange.data.Table.from_numpy(domain, X, Y, M)
             data.ids = row_ids
             data.name = learner_name
+            data.attributes = self.data.attributes
 
             if selected:
                 annotated_data = create_annotated_table(data, selected)
@@ -486,7 +509,6 @@ class OWConfusionMatrix(widget.OWWidget):
 
     @classmethod
     def migrate_settings(cls, settings, version):
-        super().migrate_settings(settings, version)
         if not version:
             # For some period of time the 'selected_learner' property was
             # changed from List[int] -> int
