@@ -1,3 +1,4 @@
+import os
 import unittest
 
 import numpy as np
@@ -19,6 +20,9 @@ from Orange.widgets.utils.owlearnerwidget import OWBaseLearner
 from Orange.widgets.utils.annotated_data import (ANNOTATED_DATA_FEATURE_NAME,
                                                  ANNOTATED_DATA_SIGNAL_NAME)
 
+# For tests, let memory freeing entirely to Python / OS
+sip.setdestroyonexit(False)
+
 app = None
 
 
@@ -77,24 +81,6 @@ class WidgetTest(GuiTest):
         cls.widgets.append(report)
         OWReport.get_instance = lambda: report
 
-    @classmethod
-    def tearDownClass(cls):
-        """Cleanup after tests
-
-        Process any pending events and properly destroy created widgets by
-        calling their onDeleteWidget method which does the widget-specific
-        cleanup.
-
-        NOTE: sip.delete is mandatory. In some cases, widgets are deleted by
-        python while some references in QApplication remain
-        (QApplication::topLevelWidgets()), causing a segmentation fault when
-        QApplication is destroyed.
-        """
-        app.processEvents()
-        for w in cls.widgets:
-            w.onDeleteWidget()
-            sip.delete(w)
-
     def create_widget(self, cls, stored_settings=None, reset_default_settings=True):
         """Create a widget instance.
 
@@ -177,6 +163,9 @@ class WidgetTest(GuiTest):
             if input_signal.name == input_name:
                 getattr(widget, input_signal.handler)(value, *args)
                 break
+        else:
+            raise ValueError("'{}' is not an input name for widget {}"
+                             .format(input_name, type(widget).__name__))
         widget.handleNewSignals()
 
     def get_output(self, output_name, widget=None):
@@ -532,10 +521,12 @@ class WidgetOutputsTestMixin:
                          self.same_input_output_domain)
         np.testing.assert_array_equal(selected.X[:, :n_attr],
                                       self.data.X[selected_indices])
+        self.assertEqual(selected.attributes, self.data.attributes)
 
         # check annotated data output
         annotated = self.get_output(ANNOTATED_DATA_SIGNAL_NAME)
         self.assertEqual(n_sel, np.sum([i[feature_name] for i in annotated]))
+        self.assertEqual(annotated.attributes, self.data.attributes)
 
         # compare selected and annotated data domains
         self._compare_selected_annotated_domains(selected, annotated)
@@ -552,3 +543,55 @@ class WidgetOutputsTestMixin:
         selected_vars = selected.domain.variables + selected.domain.metas
         annotated_vars = annotated.domain.variables + annotated.domain.metas
         self.assertLess(set(selected_vars), set(annotated_vars))
+
+
+class datasets:
+    @staticmethod
+    def path(filename):
+        dirname = os.path.join(os.path.dirname(__file__), "datasets")
+        return os.path.join(dirname, filename)
+
+    @classmethod
+    def missing_data_1(cls):
+        """
+        Data set with 3 continuous features (X{1,2,3}) where all the columns
+        and rows contain at least one NaN value.
+
+        One discrete class D with NaN values
+        Mixed continuous/discrete/string metas ({X,D,S}M)
+
+        Returns
+        -------
+        data : Orange.data.Table
+        """
+        return Table(cls.path("missing_data_1.tab"))
+
+    @classmethod
+    def missing_data_2(cls):
+        """
+        Data set with 3 continuous features (X{1,2,3}) where all the columns
+        and rows contain at least one NaN value and X1, X2 are constant.
+
+        One discrete constant class D with NaN values.
+        Mixed continuous/discrete/string class metas ({X,D,S}M)
+
+        Returns
+        -------
+        data : Orange.data.Table
+        """
+        return Table(cls.path("missing_data_2.tab"))
+
+    @classmethod
+    def missing_data_3(cls):
+        """
+        Data set with 3 discrete features D{1,2,3} where all the columns and
+        rows contain at least one NaN value
+
+        One discrete class D with NaN values
+        Mixes continuous/discrete/string metas ({X,D,S}M)
+
+        Returns
+        -------
+        data : Orange.data.Table
+        """
+        return Table(cls.path("missing_data_3.tab"))
